'''
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# Data Visualization Models
Package | `__init__.py`

Interactive & Visual Models for Data Representation.

Daniel Bakas Amuchastegui\
September 3, 2019

Copyright © Semantyk 2020. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
'''

from . import article, cell, file, graph, table
from .article import *
from .cell import *
from .file import *
from .graph import *
from .table import *



'''
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# Cell
Package | `__init__.py`

Daniel Bakas Amuchastegui\
February 20, 2020

Copyright © Semantyk 2020. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
'''

from . import cell, dvm_extract_cell, multimedia_cell, text_cell
from .cell import *
from .dvm_extract_cell import *
from .multimedia_cell import *
from .text_cell import *



'''
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# BNode
Module | `bnode.py`

Daniel Bakas Amuchastegui\
May 21, 2020

Copyright © Semantyk 2020. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
'''

__all__ = ['BNode']

from ...uuid_generator import generate_uuid
from .identifier import Identifier


class BNode(Identifier):
    __slots__ = ()

    def toPython(self):
        return str(self)

    def __getnewargs__(self):
        return (str(self))

    def __new__(cls, value=None):
        return Identifier.__new__(cls, value or generate_uuid())

    def __reduce__(self):
        return (BNode, (str(self)))

    def __repr__(self):
        return "BNode('%s')" % self


'''
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# URIRef
Module | `uriref.py`

Daniel Bakas Amuchastegui\
May 21, 2020

Copyright © Semantyk 2020. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
'''

__all__ = ['URIRef']

from logging import getLogger

from .identifier import Identifier


class URIRef(Identifier):
    _invalid_chars = '<>" {}|\\^`'

    __slots__ = ()

    @staticmethod
    def is_valid(self):
        return all(map(lambda c: ord(c) > 256 or not c in URIRef._invalid_chars, self))

    def toPython(self):
        return str(self)

    def __add__(self, other):
        return self.__class__(str(self) + other)

    def __getnewargs__(self):
        return (str(self))

    def __mod__(self, other):
        return self.__class__(str(self) % other)

    def __new__(cls, value):
        if not URIRef.is_valid(value):
            getLogger(__name__).warning('%s does not look like a valid URI, trying to serialize this will break.' % value)
        return str.__new__(cls, value)

    def __radd__(self, other):
        return self.__class__(other + str(self))

    def __reduce__(self):
        return (URIRef, (str(self)))

    def __repr__(self):
        return "URIRef('%s')" % str(self)



'''
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# Venn Diagram
Module | `venn_diagram.py`

Diagram that displays all possible logical relations between a finite\
collection of different resources.

Daniel Bakas Amuchastegui\
September 3, 2019

Copyright © Semantyk 2020. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
'''


'''
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# Literal
Module | `literal.py`

Daniel Bakas Amuchastegui\
May 21, 2020

Copyright © Semantyk 2020. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
'''

# TODO
# __repr__()

__all__ = ['Literal']

from ..namespace import RDF, XSD, OWL
from .identifier import Identifier
from .uriref import URIRef


class Literal(Identifier):
    _dtypes = (
        OWL.rational,
        RDF.HTMLLiteral,
        RDF.XMLLiteral,
        XSD.boolean,
        XSD.byte,
        XSD.decimal,
        XSD.double,
        XSD.float,
        XSD.int,
        XSD.integer,
        XSD.long,
        XSD.negativeInteger,
        XSD.nonNegativeInteger,
        XSD.nonPositiveInteger,
        XSD.normalizedString,
        XSD.positiveInteger,
        XSD.short,
        XSD.string,
        XSD.token,
        XSD.unsignedByte,
        XSD.unsignedInt,
        XSD.unsignedLong,
        XSD.unsignedShort
    )

    _number_dtypes = (
        XSD.byte,
        XSD.decimal,
        XSD.double,
        XSD.float,
        XSD.int,
        XSD.integer,
        XSD.long,
        XSD.negativeInteger,
        XSD.nonNegativeInteger,
        XSD.nonPositiveInteger,
        XSD.positiveInteger,
        XSD.short,
        XSD.unsignedByte,
        XSD.unsignedInt,
        XSD.unsignedLong,
        XSD.unsignedShort
    )

    _plain_dtypes = (
        OWL.rational,
        XSD.boolean,
        XSD.decimal,
        XSD.double,
        XSD.integer
    )

    _string_dtypes = (
        RDF.HTMLLiteral,
        RDF.XMLLiteral,
        XSD.normalizedString,
        XSD.string,
        XSD.token
    )

    __slots__ = ('_datatype', '_language', '_value')

    @property
    def datatype(self):
        return self._datatype

    @property
    def language(self):
        return self._language

    @property
    def value(self):
        return self._value

    @staticmethod
    def is_valid_language(value):
        return bool(compile('^[a-zA-Z]+(?:-[a-zA-Z0-9]+)*$').match(value))

    def __abs__(self):
        if isinstance(self.value, (int, float)):
            return Literal(self.value.__abs__())
        else:
            raise TypeError("Not a number; %s" % repr(self))

    def __bool__(self):
        if self.value:
            return bool(self.value)
        return len(self) != 0

    def __invert__(self):
        if isinstance(self.value, (int, float)):
            return Literal(self.value.__invert__())
        else:
            raise TypeError("Not a number; %s" % repr(self))

    def __getstate__(self):
        return (None, dict(language=self.language, datatype=self.datatype))

    def __neg__(self):
        if isinstance(self.value, (int, float)):
            return Literal(self.value.__neg__())
        else:
            raise TypeError("Not a number; %s" % repr(self))

    def __new__(cls, value, language=None, datatype=None):
        literal = str.__new__(cls, value)
        literal._value = value
        literal._language = language
        literal._datatype = datatype
        return literal

    def __pos__(self):
        if isinstance(self.value, (int, float)):
            return Literal(self.value.__pos__())
        else:
            raise TypeError("Not a number; %s" % repr(self))

    def __reduce__(self):
        return (Literal, (str(self), self.language, self.datatype))


# -*- coding: utf-8 -*-
##################################################
#
# test.py 
# Module | Test
#
# A file for testing the package.
#
# Author: Daniel Bakas Amuchastegui
# May 13, 2020
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################

import sys
import tkinter

def main():
    root = tkinter.Tk()
    root.title('Semantyk')
    root.resizable(width=False, height=False)
    root.mainloop()
if __name__ == '__main__': 
    main()


'''
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# Namespace
Module | `namespace.py`

Daniel Bakas Amuchastegui\
May 21, 2020

Copyright © Semantyk 2020. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
'''

__all__ = [
    'CSVW',
    'DC',
    'DCAT',
    'DCTERMS',
    'DOAP',
    'FOAF',
    'Namespace',
    'ODRL2',
    'ORG',
    'OWL',
    'PROF',
    'PROV',
    'QB',
    'RDF',
    'RDFS',
    'SDO',
    'SH',
    'SKOS',
    'SMTK',
    'SOSA',
    'SSN',
    'TIME',
    'XMLNS',
    'XSD',
    'VOID'
]

from .identifier.uriref import URIRef


class Namespace(str):
    __slots__ = ()

    def term(self, name):
        return URIRef(self + (name if isinstance(name, str) else ''))

    def __getattr__(self, name):
        if name.startswith('__'):
            raise AttributeError
        return self.term(name)

    def __getitem__(self, key):
        return self.term(key)

    def __new__(cls, value):
        try:
            namespace = str.__new__(cls, value)
        except UnicodeDecodeError:
            namespace = str.__new__(cls, value, "utf-8")
        return namespace

    def __repr__(self):
        return "Namespace('%s')" % self

CSVW = Namespace('http://www.w3.org/ns/csvw#')
DC = Namespace('http://purl.org/dc/elements/1.1/')
DCAT = Namespace('http://www.w3.org/ns/dcat#')
DCTERMS = Namespace('http://purl.org/dc/terms/')
DOAP = Namespace('http://usefulinc.com/ns/doap#')
FOAF = Namespace('http://xmlns.com/foaf/0.1/')
ODRL2 = Namespace('http://www.w3.org/ns/odrl/2/')
ORG = Namespace('http://www.w3.org/ns/org#')
OWL = Namespace('http://www.w3.org/2002/07/owl#')
PROF = Namespace('http://www.w3.org/ns/dx/prof/')
PROV = Namespace('http://www.w3.org/ns/prov#')
QB = Namespace('http://purl.org/linked-data/cube#')
RDF = Namespace('http://www.w3.org/1999/02/22-rdf-syntax-ns#')
SDO = Namespace('https://schema.org/')
SH = Namespace('http://www.w3.org/ns/shacl#')
RDFS = Namespace('http://www.w3.org/2000/01/rdf-schema#')
SKOS = Namespace('http://www.w3.org/2004/02/skos/core#')
SMTK = Namespace('https://raw.githubusercontent.com/semantyk/Semantyk/master/Archive/archive.ttl/')
SOSA = Namespace('http://www.w3.org/ns/sosa/')
SSN = Namespace('http://www.w3.org/ns/ssn/')
TIME = Namespace('http://www.w3.org/2006/time#')
XMLNS = Namespace('http://www.w3.org/XML/1998/namespace')
XSD = Namespace('http://www.w3.org/2001/XMLSchema#')
VOID = Namespace('http://rdfs.org/ns/void#')



'''
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# Graph
Package | `__init__.py`

Daniel Bakas Amuchastegui\
March 16, 2020

Copyright © Semantyk 2020. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
'''

from . import chart, graph, network, timeline, venn_diagram
from .chart import *
from .graph import *
from .network import *
from .timeline import *
from .venn_diagram import *



'''
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# Identifier
Module | `identifier.py`

Daniel Bakas Amuchastegui\
May 21, 2020

Copyright © Semantyk 2020. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
'''

__all__ = ['Identifier']

from collections import defaultdict
from ..node import Node


class Identifier(Node, str):
    _order = defaultdict(int)
    _order.update({'BNode': 1, 'Variable': 2, 'URIRef': 3, 'Literal': 4})

    __slots__ = ()
    __hash__ = str.__hash__

    def __eq__(self, other):
        if type(self) == type(other):
            return str(self) == str(other)
        return False

    def __ge__(self, other):
        if self.__gt__(other):
            return True
        return self == other

    def __gt__(self, other):
        if other is None:
            return True
        elif type(self) == type(other):
            return str(self) > str(other)
        elif isinstance(other, Node):
            self_class = str(type(self).__name__)
            other_class = str(type(other).__name__)
            return _order[self_class] > _order[other_class]
        return NotImplemented

    def __le__(self, other):
        if self.__lt__(other):
            return True
        return self == other

    def __lt__(self, other):
        if other is None:
            return False
        elif type(self) == type(other):
            return str(self) < str(other)
        elif isinstance(other, Node):
            self_class = str(type(self).__name__)
            other_class = str(type(other).__name__)
            return _order[self_class] < _order[other_class]
        return NotImplemented

    def __ne__(self, other):
        return not self.__eq__(other)

    def __new__(cls, value):
        return str.__new__(cls, value)

    def __repr__(self):
        return "Identifier('%s')" % self



'''
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# Semantyk 
Package | `__init__.py`

Daniel Bakas Amuchastegui\
August 31, 2017

Copyright © Semantyk 2020. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
'''

__author__ = 'Daniel Bakas Amuchastegui'
__date__ = '2020-05-21'
__email__ = 'danielbakas@gmail.com'
__version__ = '0.0.0.60'

from . import (archive, av_reality, core, das, dots, dvm, games, learn, sam,
               store, tools, uuid_generator)
from .archive import *
from .av_reality import *
from .core import *
from .dots import *
from .dvm import *
from .games import *
from .learn import *
from .sam import *
from .store import *
from .tools import *
from .uuid_generator import *



'''
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# Graph
Module | `graph.py`

Daniel Bakas Amuchastegui\
May 21, 2020

Copyright © Semantyk 2020. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
'''

# TODO
# collection() 
# de_skolemize()
# parse()
# query()
# resource()
# serialize()
# seq()
# triples()
# update()
# value()
# _get_namespace_manager()
# namespace_manager = property()

__all__ = ['Graph'] 

import random

from .identifier.bnode import BNode
from .identifier.uriref import URIRef
from .namespace import RDF, RDFS, SKOS
from .node import Node


class Graph(Node):
    def absolutize(self, uri, defrag=1):
        return self.namespace_manager.absolutize(uri, defrag)

    def add(self, triple):
        s, p, o = triple
        assert isinstance(s, Node), 'Subject %s must be a Node' % (s)
        assert isinstance(p, Node), 'Predicate %s must be a Node' % (p)
        assert isinstance(o, Node), 'Object %s must be a Node' % (o)
        self.__store.add((s, p, o), self, quoted=False)

    def addN(self, quads):
        self.__store.addN(
            (s, p, o, c)
            for s, p, o, c in quads
            if isinstance(c, Graph) 
            and c.identifier is self.identifier 
            and _assertnode(s, p, o)
        )

    def all_nodes(self):
        res = set(self.objects())
        res.update(self.subjects())
        return res

    def bind(self, prefix, namespace, override=True, replace=False):
        return self.namespace_manager.bind(prefix, namespace, override=override, replace=replace)

    def close(self, commit_pending_transaction=False):
        self.__store.close(commit_pending_transaction=commit_pending_transaction)

    def comment(self, subject, default=""):
        if subject is None:
            return default
        return self.value(subject, RDFS.comment, default=default, any=True)

    def commit(self):
        self.__store.commit()

    def compute_qname(self, uri, generate=True):
        return self.namespace_manager.compute_qname(uri, generate)

    def connected(self):
        all_nodes = list(self.all_nodes())
        discovered = []
        if not all_nodes:
            return False
        visiting = [all_nodes[random.randrange(len(all_nodes))]]
        while visiting:
            x = visiting.pop()
            if x not in discovered:
                discovered.append(x)
            for new_x in self.objects(subject=x):
                if new_x not in discovered and new_x not in visiting:
                    visiting.append(new_x)
            for new_x in self.subjects(object=x):
                if new_x not in discovered and new_x not in visiting:
                    visiting.append(new_x)
        if len(all_nodes) == len(discovered):
            return True
        else:
            return False

    def destroy(self, configuration):
        self.__store.destroy(configuration)

    def isomorphic(self, other):
        if len(self) != len(other):
            return False
        for s, p, o in self:
            if not isinstance(s, BNode) and not isinstance(o, BNode):
                if not (s, p, o) in other:
                    return False
        for s, p, o in other:
            if not isinstance(s, BNode) and not isinstance(o, BNode):
                if not (s, p, o) in self:
                    return False
        return True

    def items(self, list):
        chain = set([list])
        while list:
            item = self.value(list, RDF.first)
            if item is not None:
                yield item
            list = self.value(list, RDF.rest)
            if list in chain:
                raise ValueError("List contains a recursive rdf:rest reference")
            chain.add(list)

    def label(self, subject, default=""):
        if subject is None:
            return default
        return self.value(subject, RDFS.label, default=default, any=True)

    def load(self, source, publicID=None, format="xml"):
        self.parse(source, publicID, format)

    def namespaces(self):
        for prefix, namespace in self.namespace_manager.namespaces():
            yield prefix, namespace

    def n3(self):
        return '[%s]' % self.identifier.n3()

    def objects(self, subject=None, predicate=None):
        for s, p, o in self.triples((subject, predicate, None)):
            yield o

    def open(self, configuration, create=False):
        return self.__store.open(configuration, create)

    def predicates(self, subject=None, object=None):
        for s, p, o in self.triples((subject, None, object)):
            yield p

    def predicate_objects(self, subject=None):
        for s, p, o in self.triples((subject, None, None)):
            yield p, o

    def preferredLabel(self, subject, lang=None, default=None, labelProperties=(SKOS.prefLabel, RDFS.label)):
        if default is None:
            default = []
        if lang is not None:
            if lang == "":
                def langfilter(l):
                    return l.language is None
            else:
                def langfilter(l):
                    return l.language == lang
        else:
            def langfilter(l):
                return True
        for labelProp in labelProperties:
            labels = list(filter(langfilter, self.objects(subject, labelProp)))
            if len(labels) == 0:
                continue
            else:
                return [(labelProp, l) for l in labels]
        return default

    def qname(self, uri):
        return self.namespace_manager.qname(uri)

    def remove(self, triple):
        self.__store.remove(triple, context=self)

    def rollback(self):
        self.__store.rollback()

    def set(self, triple):
        (subject, predicate, object_) = triple
        assert (subject is not None), "s can't be None in .set([s,p,o]), as it would remove (*, p, *)"
        assert (predicate is not None), "p can't be None in .set([s,p,o]), as it would remove (s, *, *)"
        self.remove((subject, predicate, None))
        self.add((subject, predicate, object_))

    def skolemize(self, new_graph=None, bnode=None, authority=None, basepath=None):
        def do_skolemize(bnode, t):
            (s, p, o) = t
            if s == bnode:
                s = s.skolemize(authority=authority, basepath=basepath)
            if o == bnode:
                o = o.skolemize(authority=authority, basepath=basepath)
            return s, p, o
        def do_skolemize2(t):
            (s, p, o) = t
            if isinstance(s, BNode):
                s = s.skolemize(authority=authority, basepath=basepath)
            if isinstance(o, BNode):
                o = o.skolemize(authority=authority, basepath=basepath)
            return s, p, o
        retval = Graph() if new_graph is None else new_graph
        if bnode is None:
            self._process_skolem_tuples(retval, do_skolemize2)
        elif isinstance(bnode, BNode):
            self._process_skolem_tuples(retval, lambda t: do_skolemize(bnode, t))
        return retval

    def subjects(self, predicate=None, object=None):
        for s, p, o in self.triples((None, predicate, object)):
            yield s

    def subject_objects(self, predicate=None):
        for s, p, o in self.triples((None, predicate, None)):
            yield s, o

    def subject_predicates(self, object=None):
        for s, p, o in self.triples((None, None, object)):
            yield s, p

    def transitiveClosure(self, func, arg, seen=None):
        if seen is None:
            seen = {}
        elif arg in seen:
            return
        seen[arg] = 1
        for rt in func(arg, self):
            yield rt
            for rt_2 in self.transitiveClosure(func, rt, seen):
                yield rt_2

    def transitive_objects(self, subject, property, remember=None):
        if remember is None:
            remember = {}
        if subject in remember:
            return
        remember[subject] = 1
        yield subject
        for object in self.objects(subject, property):
            for o in self.transitive_objects(object, property, remember):
                yield o

    def transitive_subjects(self, predicate, object, remember=None):
        if remember is None:
            remember = {}
        if object in remember:
            return
        remember[object] = 1
        yield object
        for subject in self.subjects(predicate, object):
            for s in self.transitive_subjects(predicate, subject, remember):
                yield s

    def toPython(self):
        return self

    def triples_choices(self, triple, context=None):
        subject, predicate, object_ = triple
        for (s, p, o), cg in self.store.triples_choices((subject, predicate, object_), context=self):
            yield s, p, o

    @staticmethod
    def _assertnode(*terms):
        for t in terms:
            assert isinstance(t, Node), "Term %s must be an rdflib term" % (t)
        return True

    def _get_identifier(self):
        return self.__identifier
    identifier = property(_get_identifier)

    def _set_namespace_manager(self, namespace_manager):
        self.__namespace_manager = namespace_manager

    def _get_store(self):
        return self.__store
    store = property(_get_store)

    def _process_skolem_tuples(self, target, func):
        for t in self.triples((None, None, None)):
            target.add(func(t))

    def __add__(self, other):
        retval = Graph()
        for (prefix, uri) in set(list(self.namespaces()) + list(other.namespaces())):
            retval.bind(prefix, uri)
        for x in self:
            retval.add(x)
        for y in other:
            retval.add(y)
        return retval

    def __cmp__(self, other):
        if other is None:
            return -1
        elif isinstance(other, Graph):
            return (self.identifier > other.identifier) - (self.identifier < other.identifier)
        else:
            return 1

    def __contains__(self, triple):
        for triple in self.triples(triple):
            return True
        return False

    def __eq__(self, other):
        return isinstance(other, Graph) and self.identifier == other.identifier

    def __ge__(self, other):
        return self > other or self == other

    def __getitem__(self, item):
        pass

    def __gt__(self, other):
        return (isinstance(other, Graph) and self.identifier > other.identifier) or (other is not None)

    def __hash__(self):
        return hash(self.identifier)

    def __iadd__(self, other):
        self.addN((s, p, o, self) for s, p, o in other)
        return self

    def __init__(self, store='default', identifier=None, namespace_manager=None, base=None):
        pass

    def __isub__(self, other):
        for triple in other:
            self.remove(triple)
        return self

    def __iter__(self):
        return self.triples((None, None, None))

    def __le__(self, other):
        return self < other or self == other

    def __len__(self):
        return self.__store.__len__(context=self)

    def __lt__(self, other):
        return (other is None) or (isinstance(other, Graph) and self.identifier < other.identifier)

    def __mul__(self, other):
        retval = Graph()
        for x in other:
            if x in self:
                retval.add(x)
        return retval

    def __reduce__(self):
        return (Graph, (self.store, self.identifier))
        
    def __repr__(self):
        return '<Graph identifier=%s (%s)>' % (self.identifier, type(self))

    def __str__(self):
        if isinstance(self.identifier, URIRef):
            return ('%s a rdfg:Graph;rdflib:storage ' + "[a rdflib:Store;rdfs:label '%s'].") % (self.identifier.n3(), self.store.__class__.__name__)
        else:
            return ('[a rdfg:Graph;rdflib:storage ' + "[a rdflib:Store;rdfs:label '%s']].") % self.store.__class__.__name__

    def __sub__(self, other):
        retval = Graph()
        for x in self:
            if x not in other:
                retval.add(x)
        return retval

    def __xor__(self, other):
        return (self - other) + (other - self)

    __and__ = __mul__
    __or__ = __add__



from setuptools import find_packages, setup
import semantyk

with open('README.md', 'r') as fh:
    long_description = fh.read()

setup(
    author = semantyk.__author__,    
    author_email = semantyk.__email__,    
    classifiers = [
        'Development Status :: 1 - Planning',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8'
    ],
    description = 'Ideas Wonder.',    
    install_requires = ['rdflib', 'uuid'],
    keywords = 'semantyk',
    license = 'LICENSE.txt',
    long_description = long_description,
    long_description_content_type = 'text/markdown',
    maintainer = 'Semantyk',
    name = 'semantyk',
    packages = find_packages(
        exclude = {
            'docs',
            'tests*'
        }
    ),
    url = 'https://github.com/semantyk/Semantyk',
    version = semantyk.__version__
)


# -*- coding: utf-8 -*-
##################################################
#
# test_import.py 
# Module | Test Import
#
# A file for testing the import of the package.
#
# Author: Daniel Bakas Amuchastegui
# May 13, 2020
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################

import semantyk

def test_import():
    print('Semantyk ' + semantyk.__version__)

test_import()